==> php-residence-mod-de_0.3.3.tar.gz: de/creadb.php <==
<?php

switch ($messaggio) {

case "Inserimento dei dati permanenti":  	$messaggio = "Permanente Daten eingeben"; break;
case "Inserisci questi dati per poi creare il database":	$messaggio = "Geben Sie diese Daten ein damit die Datenbank erstellt werden kann."; break;
case "Nome del database da utilizzare":		$messaggio = "Name der Datenbank"; break;
case "Nome del computer a cui collegarsi":  	$messaggio = "Name des Datenbankservers (Hostname)"; break;
case "Numero della porta a cui collegarsi":  	$messaggio = "Port f&uuml;r die Datenbank"; break;
case "Nome per l'autenticazione al database":  	$messaggio = "Benutzername f&uuml;r die Datenbank"; break;
case "Parola segreta per l'autenticazione al database":	$messaggio = "Passwort f&uuml;r die Datenbank"; break;
case "Caricare la libreria dinamica \"pgsql.so\" o \"mysql.so\"":	$messaggio = "Dynamische Bibliotheken \"pgsql.so\" oder \"mysql.so\" laden"; break;
case "No":  					$messaggio = "Nein"; break;
case "Si":  					$messaggio = "Ja"; break;
case "scegliere si se non viene caricata automaticamente da php":	$messaggio = "w&auml;hlen Sie \"Ja\", wenn es nicht automatisch von PHP gestartet wird."; break;
case "Nome del database a cui collegarsi temporaneamente":	$messaggio = "Name der Datenbank zu der tempor&auml;r verbunden werden soll."; break;
case "Numero di appartamenti da gestire":  	$messaggio = "Anzahl der zu verwaltenden Apartments"; break;
case "Crea il database":  			$messaggio = "Datenbank erzeugen"; break;
case "Database creato":  			$messaggio = "Datenbank erzeugt"; break;
case "Inserisci ora i dati sugli appartamenti":	$messaggio = "Geben Sie jetzt die Daten Ihrer Apartments ein"; break;
case "almeno il numero, diverso per ogni appartamento":	$messaggio = "die Nummer, f&uuml;r jedes Apartment unterschiedlich"; break;
case "Numero (o nome) dell' appartamento":  	$messaggio = "Nummer (oder Name) des Apartments"; break;
case "Massimo numero di occupanti":  		$messaggio = "Maximale Anzahl der Personen f&uuml;r das Apartment"; break;
case "Numero (o nome) piano":  				$messaggio = "Flur Name oder Nummer"; break;
case "Numero (o nome) casa":  				$messaggio = "Hausnummer oder Name"; break;
case "Priorit (pi bassa , prima viene assegnato)":	$messaggio = "Priorit&auml;t (die niedrigste wird zuerst belegt)"; break;
case "Inserisci i dati sugli appartamenti":  	$messaggio = "Geben Sie  die Daten Ihrer Apartments ein"; break;
case "Non  stato possibile creare il database, controllare i privilegi dell' utente, il nome del database o se esiste gi un database chiamato":
						$messaggio = "Es ist nicht m&ouml;glich die Datenbank zu erstellen. Bitte &uuml;berpr&uuml;fen Sie ob sie die n&ouml;tigen Rechte haben oder falls sie bereits existiert ob sie auch folgenden Namen hat"; break;
case "I dati inseriti non sono esatti o il server postgres non  in ascolto (assicurarsi che venga avviato con -i e di avere i permessi giusti in pg_hba.conf)":
						$messaggio = "Die eingegebenen Daten sind falsch oder der Server h&ouml;rt nicht. Stellen Sie sicher, da&szlig; er mit -i startet und sie die richtigen Rechte auf die pg_hba.conf haben."; break;
case "Torna indietro":  			$messaggio = "Zur&uuml;ck"; break;
case "Dati inseriti":  				$messaggio = "Daten eingetragen"; break;
case "Tutti i dati permanenti sono stati inseriti":	$messaggio = "Alle permanenten Daten wurden eingetragen"; break;
case "Non ho i permessi di scrittura sulla directory dati, cambiarli e reiniziare l'installazione":	$messaggio = "Keine Schreibrechte auf den \"dati\" Ordner. Bitte &auml;ndern Sie das und starten Sie die Installation neu."; break;
case "Tipo di database":			$messaggio = "Datenbank Typ"; break;
case "Database gi esistente":			$messaggio = "Existierende Datenbank"; break;
case "Se gi esistente e non vuoto usare un prefisso non presente nel database per il nome delle tabelle":	$messaggio = "Sollte sie existieren verwenden Sie ein Prefix f&uuml;r die Tabellen"; break;
case "Normalmete 5432 per Postgresql o 3306 per Mysql":	$messaggio = "Normalerweise 5432 f&uuml;r Postgresql oder 3306 f&uuml;r Mysql"; break;
case "solo per Postgresql con database non esistente":	$messaggio = "nur f&uuml;r Postgresql ohne existierende Datenbank"; break;
case "Prefisso nel nome delle tabelle":		$messaggio = "Prefix in Tabellenname"; break;
case "opzionale, utile per pi installazioni di php-residence nello stesso database":	$messaggio = "optional, n&uuml;tzlich f&uuml;r mehrere Installationen von php-residence in der gleichen Datenbank"; break;
case "Il prefisso del nome delle tabelle  sbagliato (accettate solo lettere minuscole, numeri e _ , primo carattere lettera)":	$messaggio = "Das Prefix der Tabellen ist falsch ( nur Kleinbuchstaben, Nummern und _ am Anfang)"; break;
case "":					$messaggio = ""; break;
case "":					$messaggio = ""; break;
case "":					$messaggio = ""; break;
case "":					$messaggio = ""; break;
case "":					$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> php-residence-mod-de_1.1.1-1.tar.gz: de/creadb.php <==
<?php

switch ($messaggio) {

case "Inserimento dei dati permanenti":  	$messaggio = "Permanente Daten eingeben"; break;
case "Inserisci questi dati per poi creare il database":	$messaggio = "Geben Sie diese Daten ein damit die Datenbank erstellt werden kann."; break;
case "Nome del database da utilizzare":		$messaggio = "Name der Datenbank"; break;
case "Nome del computer a cui collegarsi":  	$messaggio = "Name des Datenbankservers (Hostname)"; break;
case "Numero della porta a cui collegarsi":  	$messaggio = "Port f&uuml;r die Datenbank"; break;
case "Nome per l'autenticazione al database":  	$messaggio = "Benutzername f&uuml;r die Datenbank"; break;
case "Parola segreta per l'autenticazione al database":	$messaggio = "Passwort f&uuml;r die Datenbank"; break;
case "Caricare la libreria dinamica \"pgsql.so\" o \"mysql.so\"":	$messaggio = "Dynamische Bibliotheken \"pgsql.so\" oder \"mysql.so\" laden"; break;
case "No":  					$messaggio = "Nein"; break;
case "Si":  					$messaggio = "Ja"; break;
case "scegliere si se non viene caricata automaticamente da php":	$messaggio = "w&auml;hlen Sie \"Ja\", wenn es nicht automatisch von PHP gestartet wird."; break;
case "Nome del database a cui collegarsi temporaneamente":	$messaggio = "Name der Datenbank zu der tempor&auml;r verbunden werden soll."; break;
case "Numero di appartamenti da gestire":  	$messaggio = "Anzahl der zu verwaltenden Apartments"; break;
case "Crea il database":  			$messaggio = "Datenbank erzeugen"; break;
case "Database creato":  			$messaggio = "Datenbank erzeugt"; break;
case "Inserisci ora i dati sugli appartamenti":	$messaggio = "Geben Sie jetzt die Daten Ihrer Apartments ein"; break;
case "almeno il numero, diverso per ogni appartamento":	$messaggio = "f&uuml;r jedes Apartment eine andere Nummer"; break;
case "Numero (o nome) dell' appartamento":  	$messaggio = "Nummer (oder Name) des Apartments"; break;
case "Massimo numero di occupanti":  		$messaggio = "Maximale Anzahl der Personen f&uuml;r das Apartment"; break;
case "Numero (o nome) piano":  				$messaggio = "Flur Name oder Nummer"; break;
case "Numero (o nome) casa":  				$messaggio = "Hausnummer oder Name"; break;
case "Priorità (più bassa è, prima viene assegnato)":	$messaggio = "Priorit&auml;t (die niedrigste wird zuerst belegt)"; break;
case "Inserisci i dati sugli appartamenti":  	$messaggio = "Geben Sie  die Daten Ihrer Apartments ein"; break;
case "Non è stato possibile creare il database, controllare i privilegi dell' utente, il nome del database o se esiste già un database chiamato": 						$messaggio = "It hasn't been possible to create the database, check the user privileges, the name of the database or if already exists a database called"; break;
						$messaggio = "It hasn't been possible to create the database, check the user privileges, the name of the database or if already exists a database called"; break;
case "I dati inseriti non sono esatti o il database non è in ascolto (se postgres assicurarsi che venga avviato con -i e di avere i permessi giusti in pg_hba.conf)": 						$messaggio = "Inserted data isn't exact or the database isn't listening (if it's postgres make sure it is started with -i and you have right permissions in pg_hba.conf)"; break;
						$messaggio = "Inserted data isn't exact or the database isn't listening (if it's postgres make sure it is started with -i and you have right permissions in pg_hba.conf)"; break;
case "Torna indietro":  			$messaggio = "Zur&uuml;ck"; break;
case "Dati inseriti":  				$messaggio = "Daten eingetragen"; break;
case "Tutti i dati permanenti sono stati inseriti":	$messaggio = "Alle permanenten Daten wurden eingetragen"; break;
case "Non ho i permessi di scrittura sulla directory dati, cambiarli e reiniziare l'installazione":	$messaggio = "Keine Schreibrechte auf den \"dati\" Ordner. Bitte &auml;ndern Sie das und starten Sie die Installation neu."; break;
case "Tipo di database":			$messaggio = "Datenbank Typ"; break;
case "Database già esistente":			$messaggio = "Existierende Datenbank"; break;
case "Se già esistente e non vuoto usare un prefisso non presente nel database per il nome delle tabelle":	$messaggio = "Sollte sie existieren verwenden Sie ein Prefix f&uuml;r die Tabellen"; break;
case "Normalmete 5432 per Postgresql o 3306 per Mysql":	$messaggio = "Normalerweise 5432 f&uuml;r Postgresql oder 3306 f&uuml;r Mysql"; break;
case "solo per Postgresql con database non esistente":	$messaggio = "nur f&uuml;r Postgresql ohne existierende Datenbank"; break;
case "Prefisso nel nome delle tabelle":		$messaggio = "Prefix in Tabellenname"; break;
case "opzionale, utile per più installazioni di php-residence nello stesso database":	$messaggio = "optional, n&uuml;tzlich f&uuml;r mehrere Installationen von php-residence in der gleichen Datenbank"; break;
case "Il prefisso del nome delle tabelle è sbagliato (accettate solo lettere minuscole, numeri e _ , primo carattere lettera)":	$messaggio = "Das Prefix der Tabellen ist falsch ( nur Kleinbuchstaben, Nummern und _ am Anfang)"; break;
case "":					$messaggio = ""; break;
case "":					$messaggio = ""; break;
case "":					$messaggio = ""; break;
case "":					$messaggio = ""; break;
case "":					$messaggio = ""; break;

} # fine switch ($messaggio)

?>
